@@ -1,5 +1,5 @@
 ;; shepherd.scm -- The daemon shepherd.
-;; Copyright (C) 2013-2014, 2016, 2018-2020, 2022-2023 Ludovic Courtès <ludo@gnu.org>
+;; Copyright (C) 2013-2014, 2016, 2018-2020, 2022-2024 Ludovic Courtès <ludo@gnu.org>
 ;; Copyright (C) 2002, 2003 Wolfgang Jährling <wolfgang@pro-linux.de>
 ;; Copyright (C) 2018 Carlo Zancanaro <carlo@zancanaro.id.au>
 ;; Copyright (C) 2018 Danny Milosavljevic <dannym@scratchpost.org>
@@ -479,7 +479,9 @@ fork in the child process."
                 ;; When in a separate PID namespace, we get EINVAL (see
                 ;; 'reboot_pid_ns' in kernel/pid_namespace.c.)  We get EPERM in
                 ;; a user namespace that lacks CAP_SYS_BOOT.
-                (unless (member err (list EINVAL EPERM))
+                ;; ENOSYS is returned in runc environments due to seccomp
+                ;; defaults: <https://github.com/opencontainers/runc/pull/2750>.
+                (unless (member err (list EINVAL EPERM ENOSYS))
                   (apply throw args)))))
 
           ;; Load the SIGSEGV/SIGABRT handler.  This is what allows PID 1 to
